bayespy.inference.vmp.nodes.gaussian.WrapToGaussianWishart.set_plotter
======================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: WrapToGaussianWishart.set_plotter